# Retrieve package parameters
$PackageParameters = Get-PackageParameters
$sGenericRepo = $PackageParameters['GenericRepo']
 
$ErrorActionPreference = 'Stop'; # stop on all errors
$ResultCode = 0
# Log function
function LogOutput([string]$sText, [string]$sLogFile) {  # format output to LogFile
   $TimeStamp = [System.DateTime]::Now.tostring("dd.MM.yyyy HH:mm:ss")
   $sOut = "["+$TimeStamp+"] "+$sText
   write-Output  $sOut
}
 
 
# If $sGenericRepo is blank, then it has been called outide Puppet
 
if ($sGenericRepo -eq $null) {
  LogOutput "WRN - Parameters not passed, therefore not called from Puppet"
  LogOutput "WRN - therefore need to calculate the following,GenericRepo"
  [string]$sSource = (IEX "choco source") | Select-String -Pattern "artifactory"
  $sRepoSource = "https:"+($sSource.split("|")[0]).split(":")[1]
  $s = $sRepoSource.split("/")
  $sGenericRepo = $s[0]+"//"+$s[2]+"/"+$s[3]+"/axa_gen_prod"
}
LogOutput "INF - sGenericRepo: $sGenericRepo"
 
# Download the Binary to install
 
$packageName= 'windows_exporter'
$toolsDir   = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$fileToDownload = "windows_exporter-0.19.0-amd64.msi"
$url        = $sGenericRepo + "/" + $packageName +"/" + $fileToDownload
$url64      = $sGenericRepo + "/" + $packageName +"/" + $fileToDownload
$checksum64 = '398fdf5617eca81b8d24f8e226b0bad57055e4e220741bb158b921b6e10848ba'
$sDownloadedFile = "C:\Windows\Temp\$fileToDownload"
LogOutput "INF - sDownloadedFile is $sDownloadedFile"
LogOutput "INF - url64 is $url64"
 
$pp = Get-PackageParameters
 
$silentArgs = "/quiet /norestart /l*v `"$($env:TEMP)\$($packageName).$($env:chocolateyPackageVersion).MsiInstall.log`""
 
if ($PackageParameters["EnabledCollectors"] -ne $null -and $PackageParameters["EnabledCollectors"] -ne '') {
  $silentArgs += " ENABLED_COLLECTORS=$($PackageParameters["EnabledCollectors"])"
  Write-Host "Collectors: `'$($PackageParameters["EnabledCollectors"])`'"
}
 
if ($PackageParameters["ListenAddress"] -ne $null -and $PackageParameters["ListenAddress"] -ne '') {
  $silentArgs += " LISTEN_ADDR=$($PackageParameters["ListenAddress"])"
  LogOutput "INF - Listen Address: `'$($PackageParameters["ListenAddress"])`'"
}
 
if ($PackageParameters["ListenPort"] -ne $null -and $PackageParameters["ListenPort"] -ne '') {
  $silentArgs += " LISTEN_PORT=$($PackageParameters["ListenPort"])"
  LogOutput "INF - Listen Port: `'$($PackageParameters["ListenPort"])`'"
}
 
if ($PackageParameters["MetricsPath"] -ne $null -and $PackageParameters["MetricsPath"] -ne '') {
  $silentArgs += " METRICS_PATH=$($PackageParameters["MetricsPath"])"
  LogOutput "INF - Metrics Path: `'$($PackageParameters["MetricsPath"])`'"
}
 
if ($PackageParameters["TextFileDir"] -ne $null -and $PackageParameters["TextFileDir"] -ne '') {
  $silentArgs += " TEXTFILE_DIR=$($PackageParameters["TextFileDir"])"
  LogOutput "INF - Textfile Directory: `'$($PackageParameters["TextFileDir"])`'"
}
 
if ($PackageParameters["ExtraFlags"] -ne $null -and $pp["ExtraFlags"] -ne '') {
  $silentArgs += " EXTRA_FLAGS=$($pp["ExtraFlags"])"
  LogOutput "INF - Extra flags: `'$($pp["ExtraFlags"])`'"
}
 
$packageArgs = @{
  packageName   = $packageName
  unzipLocation = $toolsDir
  fileType      = 'MSI'
  url           = $url
  url64bit      = $url64
 
  softwareName  = 'windows_exporter*'
 
  checksum      = ''
  checksumType  = 'sha256'
  checksum64    = '398FDF5617ECA81B8D24F8E226B0BAD57055E4E220741BB158B921B6E10848BA'
  checksumType64= 'sha256'
 
  silentArgs    = $silentArgs
  validExitCodes= @(0, 3010, 1641)
}
 
Install-ChocolateyPackage @packageArgs
